FondeActionButtonColors class

Class defining action button colors For overlay action buttons (e.g., ellipsis menu button in stack grid)

Constructors

FondeActionButtonColors({required Color background, required Color iconColor})
const

Properties

background Color
Action button background color
final
hashCode int
The hash code for this object.
no setteroverride
iconColor Color
Action button icon color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? background, Color? iconColor}) FondeActionButtonColors
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override