FondeContextMenuDivider class

A divider for use in a FondeContextMenu items list.

Inheritance

Constructors

FondeContextMenuDivider()
Create FondeContextMenuDivider
const

Properties

enabled bool
Whether this item is enabled
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isDangerous bool
Whether this item represents a dangerous operation (displayed in error color)
finalinherited
label String
Item label
finalinherited
onPressed VoidCallback
Callback when item is pressed
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited