FondeExpansionIconPosition enum

Enum to specify the icon position of ExpansionTile.

Inheritance
Available extensions

Values

leading → const FondeExpansionIconPosition

Displays the icon on the left side (start).

trailing → const FondeExpansionIconPosition

Displays the icon on the right side (end).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FondeExpansionIconPosition>
A constant List of the values in this enum, in order of their declaration.