FondePopoverAnimation enum

Animation type for FondePopover

Inheritance
Available extensions

Values

scaleAndFade → const FondePopoverAnimation

Scale + Fade (default recommended)

slideAndFade → const FondePopoverAnimation

Slide + Fade

elastic → const FondePopoverAnimation

Elastic

fade → const FondePopoverAnimation

Simple Fade

none → const FondePopoverAnimation

No animation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FondePopoverAnimation>
A constant List of the values in this enum, in order of their declaration.