FondeSegmentedButton<T extends Object> class

A themed segmented button that automatically applies colors from FondeColorConfig.

Inheritance

Constructors

FondeSegmentedButton({required Set<T> selected, required List<ButtonSegment<T>> segments, required ValueChanged<Set<T>> onSelectionChanged, bool disableZoom = false, Key? key})
Creates a themed segmented button.
const

Properties

disableZoom bool
Whether to disable zoom functionality.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelectionChanged ValueChanged<Set<T>>
The callback that is called when the selection changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<ButtonSegment<T>>
The configuration for each segment in the button.
final
selected Set<T>
The set of segments currently selected.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited