build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
final appColorScheme = context.fondeColorScheme;
final accessibilityConfig = context.fondeAccessibility;
final zoomScale = disableZoom ? 1.0 : accessibilityConfig.zoomScale;
final borderScale = disableZoom ? 1.0 : accessibilityConfig.borderScale;
return SegmentedButton<T>(
segments: segments,
selected: selected,
onSelectionChanged: onSelectionChanged,
showSelectedIcon: false, // Disable checkbox display
style: SegmentedButton.styleFrom(
// Use base background color
backgroundColor: appColorScheme.base.background,
// Use theme color when selected
selectedBackgroundColor: appColorScheme.theme.primaryColor.withValues(
alpha: 0.1,
),
// Text color when not selected
foregroundColor: appColorScheme.base.foreground,
// Text color when selected (theme color)
selectedForegroundColor: appColorScheme.theme.primaryColor,
side: BorderSide(
// Border color
color: appColorScheme.base.border,
width: FondeBorderWidth.medium * borderScale,
),
// Conforms to design guidelines: Build shape from context
// Prevent animation: Use consistent shape object
shape: SquircleBorder(
borderRadius: SquircleBorderRadius(
cornerRadius: 8.0,
cornerSmoothing: 0.6,
),
side: BorderSide(color: appColorScheme.base.border, width: 1.5),
),
// TextStyle conforming to FondeTextVariant (zoom support is automatic)
textStyle: Theme.of(context).textTheme.labelMedium?.copyWith(
fontSize:
(Theme.of(context).textTheme.labelMedium?.fontSize ?? 14.0) *
zoomScale,
),
// Zoom support: Icon size is also adjusted
iconSize: 18.0 * zoomScale,
// Zoom support: Ensure minimum tap target size (design guideline: 44px or more)
minimumSize: Size(44.0 * zoomScale, 44.0 * zoomScale),
// Disable animation: Prevent unnecessary animation during zoom
animationDuration: Duration.zero,
// Disable ripple animation: Disable ripple effect on tap
splashFactory: NoSplash.splashFactory,
),
);
}