FondeSelectionState<T> class

Helper class for managing selection state.

Used when managing multiple selectable items.

Constructors

FondeSelectionState()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasSelection bool
Whether anything is selected.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCount int
Number of selected items.
no setter
selectedItems Set<T>
Set of selected items.
no setter

Methods

clearSelection() → void
Clear all selections.
deselect(T item) → void
Deselect an item.
isSelected(T item) bool
Whether an item is selected.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(T item) → void
Select an item.
toggle(T item) → void
Toggle the selection state of an item.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited