fonde_ui_riverpod library

Riverpod integration for fonde_ui.

Import this library in addition to fonde_ui.dart to access Riverpod-based state providers for themes, navigation, layout, and more.

Classes

EffectiveColorSchemeWithThemeProvider
Based on the current theme, system brightness settings, and theme color, a Provider that obtains the FondeColorScheme to be actually applied.
FondeAccessibilityConfigNotifier
Provider that manages accessibility settings.
FondeAccessibilityConfigNotifierProvider
Provider that manages accessibility settings.
FondeActiveIconTheme
Active icon theme management Provider.
FondeActiveIconThemeProvider
Active icon theme management Provider.
FondeActiveTheme
Active theme management Provider.
FondeActiveThemeProvider
Active theme management Provider.
FondeContextualSecondarySidebarStateProvider
Secondary sidebar state provider based on the current activity bar index. This provider automatically manages the state for each screen.
FondeEffectiveColorSchemeProvider
Provider that obtains the FondeColorScheme to be actually applied, based on the current theme, system brightness settings, and theme color.
FondeEffectiveFlutterColorSchemeProvider
Provider that obtains the Flutter ColorScheme to be actually applied.
FondeEffectiveThemeDataProvider
Provider that obtains the ThemeData to be actually applied.
FondeNavigationState
Provider for managing navigation state.
FondeNavigationStateData
Navigation state data class.
FondeNavigationStateProvider
Provider for managing navigation state.
FondePerScreenSecondarySidebarState
A map that manages the secondary sidebar state for each screen. Key: index of the activity bar, Value: visibility state of the sidebar.
FondePerScreenSecondarySidebarStateProvider
A map that manages the secondary sidebar state for each screen. Key: index of the activity bar, Value: visibility state of the sidebar.
FondePlatformBrightness
Provider that monitors platform brightness settings.
FondePlatformBrightnessProvider
Provider that monitors platform brightness settings.
FondePrimarySidebarState
Provider that manages the visibility state of the primary sidebar (left side).
FondePrimarySidebarStateProvider
Provider that manages the visibility state of the primary sidebar (left side).
FondeSearchFieldManager
Search field manager class.
FondeSearchFieldManagerProvider
Provider that manages the state and actions of the search field.
FondeSearchQuery
Provider that manages the current search query.
FondeSearchQueryProvider
Provider that manages the current search query.
FondeSecondarySidebarState
Provider that manages the visibility state of the secondary sidebar (right side). Manages the state for each screen based on the current activity bar index.
FondeSecondarySidebarStateProvider
Provider that manages the visibility state of the secondary sidebar (right side). Manages the state for each screen based on the current activity bar index.
FondeSecondarySidebarWidthNotifier
Provider that manages the width of the secondary sidebar.
FondeSidebarWidthNotifier
Provider that manages the width of the sidebar.
FondeThemeColorNotifierProvider
Currently selected theme color type.
FondeThemeColorSchemeProvider
Theme color scheme.
FondeToolbarActions
Toolbar actions class.
FondeToolbarActionsProvider
Provider that supplies toolbar actions.
FondeToolbarItemData
Data structure for a toolbar item.
FondeToolbarState
Model representing the state of the toolbar.
FondeToolbarStateManager
Provider that manages the state of the toolbar.
FondeToolbarStateManagerProvider
Provider that manages the state of the toolbar.

Extensions

FondeAccessibilityScaling on WidgetRef
Extension to provide easy access to accessibility scaling (Riverpod version)
FondeTextStyleBuilderRef on FondeTextStyleBuilder
Riverpod-dependent extension methods for FondeTextStyleBuilder.

Properties

effectiveColorSchemeWithThemeProvider EffectiveColorSchemeWithThemeProvider
Based on the current theme, system brightness settings, and theme color, a Provider that obtains the FondeColorScheme to be actually applied.
final
fondeAccessibilityConfigProvider FondeAccessibilityConfigNotifierProvider
Provider that manages accessibility settings.
final
fondeActiveIconThemeProvider FondeActiveIconThemeProvider
Active icon theme management Provider.
final
fondeActiveThemeProvider FondeActiveThemeProvider
Active theme management Provider.
final
fondeContextualSecondarySidebarStateProvider FondeContextualSecondarySidebarStateProvider
Secondary sidebar state provider based on the current activity bar index. This provider automatically manages the state for each screen.
final
fondeDefaultIconThemeProvider → Provider<FondeIconTheme>
The effective icon theme to use in components.
final
fondeEffectiveColorSchemeProvider FondeEffectiveColorSchemeProvider
Provider that obtains the FondeColorScheme to be actually applied, based on the current theme, system brightness settings, and theme color.
final
fondeEffectiveFlutterColorSchemeProvider FondeEffectiveFlutterColorSchemeProvider
Provider that obtains the Flutter ColorScheme to be actually applied.
final
fondeEffectiveThemeDataProvider FondeEffectiveThemeDataProvider
Provider that obtains the ThemeData to be actually applied.
final
fondeNavigationStateProvider FondeNavigationStateProvider
Provider for managing navigation state.
final
fondePerScreenSecondarySidebarStateProvider FondePerScreenSecondarySidebarStateProvider
A map that manages the secondary sidebar state for each screen. Key: index of the activity bar, Value: visibility state of the sidebar.
final
fondePlatformBrightnessProvider FondePlatformBrightnessProvider
Provider that monitors platform brightness settings.
final
fondePrimarySidebarStateProvider FondePrimarySidebarStateProvider
Provider that manages the visibility state of the primary sidebar (left side).
final
fondeSearchFieldManagerProvider FondeSearchFieldManagerProvider
Provider that manages the state and actions of the search field.
final
fondeSearchQueryProvider FondeSearchQueryProvider
Provider that manages the current search query.
final
fondeSecondarySidebarStateProvider FondeSecondarySidebarStateProvider
Provider that manages the visibility state of the secondary sidebar (right side). Manages the state for each screen based on the current activity bar index.
final
fondeThemeColorProvider FondeThemeColorNotifierProvider
Currently selected theme color type.
final
fondeThemeColorSchemeProvider FondeThemeColorSchemeProvider
Theme color scheme.
final
fondeToolbarActionsProvider FondeToolbarActionsProvider
Provider that supplies toolbar actions.
final
fondeToolbarStateManagerProvider FondeToolbarStateManagerProvider
Provider that manages the state of the toolbar.
final
secondarySidebarWidthProvider → StateNotifierProvider<FondeSecondarySidebarWidthNotifier, double>
Secondary sidebar width provider.
final
sidebarWidthProvider → StateNotifierProvider<FondeSidebarWidthNotifier, double>
Primary sidebar width provider.
final

Functions

effectiveColorSchemeWithTheme(Ref ref) FondeColorScheme
Based on the current theme, system brightness settings, and theme color, a Provider that obtains the FondeColorScheme to be actually applied.
fondeContextualSecondarySidebarState(Ref ref) bool
Secondary sidebar state provider based on the current activity bar index. This provider automatically manages the state for each screen.
fondeEffectiveColorScheme(Ref ref) FondeColorScheme
Provider that obtains the FondeColorScheme to be actually applied, based on the current theme, system brightness settings, and theme color.
fondeEffectiveFlutterColorScheme(Ref ref) ColorScheme
Provider that obtains the Flutter ColorScheme to be actually applied.
fondeEffectiveThemeData(Ref ref) ThemeData
Provider that obtains the ThemeData to be actually applied.
fondeSearchFieldManager(Ref ref) FondeSearchFieldManager
Provider that manages the state and actions of the search field.
fondeThemeColorScheme(Ref ref) FondeThemeColorScheme
Theme color scheme.
fondeToolbarActions(Ref ref) FondeToolbarActions
Provider that supplies toolbar actions.