FondeAccessibilityConfigNotifier class
Provider that manages accessibility settings.
Persistence is left to the application. Call updateConfig with a loaded FondeAccessibilityConfig to restore saved settings.
- Annotations
-
- @riverpod
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ FondeAccessibilityConfig
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → FondeAccessibilityConfig?
-
The value currently exposed by this
Notifier.no setterinherited
Methods
-
build(
) → FondeAccessibilityConfig -
listenSelf(
void listener(FondeAccessibilityConfig? previous, FondeAccessibilityConfig next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runBuild(
) → void -
Executes
Notifier.build.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateConfig(
FondeAccessibilityConfig newConfig) → void -
updateShouldNotify(
FondeAccessibilityConfig previous, FondeAccessibilityConfig next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited