FondeNavigationState class

Provider for managing navigation state.

Manages the selection state of navigation items and the expansion state of groups. Item and group identifiers are plain String values.

Annotations
  • @riverpod

Constructors

FondeNavigationState()

Properties

hashCode int
The hash code for this object.
no setterinherited
ref → Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state FondeNavigationStateData
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull FondeNavigationStateData?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() FondeNavigationStateData
clearSelection() → void
Clear the selection.
isGroupExpanded(String groupId) bool
Check if the specified group ID is expanded.
isItemSelected(String itemId) bool
Check if the specified item ID is selected.
listenSelf(void listener(FondeNavigationStateData? previous, FondeNavigationStateData next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBuild() → void
Executes Notifier.build.
inherited
selectItem(String itemId) → void
Select an item.
toggleGroup(String groupId) → void
Toggle the expansion state of a group.
toString() String
A string representation of this object.
inherited
updateShouldNotify(FondeNavigationStateData previous, FondeNavigationStateData next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited