FondeSearchQuery class
Provider that manages the current search query.
- Annotations
-
- @riverpod
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → String?
-
The value currently exposed by this
Notifier.no setterinherited
Methods
-
build(
) → String -
clearQuery(
) → void - Clear the search query.
-
listenSelf(
void listener(String? previous, String next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runBuild(
) → void -
Executes
Notifier.build.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateQuery(
String? newQuery) → void - Update the search query.
-
updateShouldNotify(
String previous, String next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited