effectiveColorSchemeWithThemeProvider top-level property

  1. @ProviderFor.new(effectiveColorSchemeWithTheme)
EffectiveColorSchemeWithThemeProvider effectiveColorSchemeWithThemeProvider
final

Based on the current theme, system brightness settings, and theme color, a Provider that obtains the FondeColorScheme to be actually applied.

Implementation

@ProviderFor(effectiveColorSchemeWithTheme)
final effectiveColorSchemeWithThemeProvider =
    EffectiveColorSchemeWithThemeProvider._();