fondeSearchFieldManager function
Provider that manages the state and actions of the search field.
Implementation
@riverpod
FondeSearchFieldManager fondeSearchFieldManager(Ref ref) {
return FondeSearchFieldManager(ref);
}
Provider that manages the state and actions of the search field.
@riverpod
FondeSearchFieldManager fondeSearchFieldManager(Ref ref) {
return FondeSearchFieldManager(ref);
}