FondeBaseColors class
Class defining base colors Basic color definitions used throughout the application
Constructors
Properties
- background → Color
-
Main background color
final
- border → Color
-
Basic border, frame color
final
- divider → Color
-
Divider color for horizontal and vertical lines
final
- foreground → Color
-
Basic text color, icon color
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → Color
-
Background color for text selection, list item selection (no transparency)
final
- shadow → Color
-
Drop shadow, elevation effect color
final
Methods
-
copyWith(
{Color? foreground, Color? background, Color? selection, Color? border, Color? divider, Color? shadow}) → FondeBaseColors -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override