FondeRadioButton<T> class
Common RadioButton for App app.
Provides a unified RadioButton style across the app. It has a circular shape, and when selected, a small circle is displayed in the center.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FondeRadioButton
Constructors
-
FondeRadioButton({Key? key, required T value, required T? groupValue, required ValueChanged<
T?> ? onChanged, double? size, FocusNode? focusNode, bool autofocus = false, String? semanticLabel, bool disableZoom = false, Color? activeColor}) -
const
Properties
- activeColor → Color?
-
Active color (uses theme color if not specified).
final
- autofocus → bool
-
Whether the radio button autofocuses.
final
- disableZoom → bool
-
Whether to disable zoom functionality.
final
- focusNode → FocusNode?
-
Focus node of the radio button.
final
- groupValue → T?
-
Currently selected group value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
T?> ? -
Callback when the value changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Semantic label.
final
- size → double?
-
Size of the radio button.
final
- value → T
-
Value of the radio button.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited