FondeStatusBarColors class
Class defining status bar colors
Constructors
Properties
- background → Color
-
Status bar background
final
- foreground → Color
-
Status text color
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- itemHoverBackground → Color
-
Status item background on hover
final
- prominentBackground → Color
-
Background for important status display (e.g., error)
final
- prominentForeground → Color
-
Text color for important status display
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? background, Color? foreground, Color? itemHoverBackground, Color? prominentBackground, Color? prominentForeground}) → FondeStatusBarColors -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override