FondeTextStyleBuilder class
A utility class that builds a TextStyle from an FondeTextVariant.
Generates a TextStyle using the same logic as the FondeText component. This allows it to automatically follow changes in the FondeTextVariant specification.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildTextStyle(
{required FondeTextVariant variant, required BuildContext context, Color? color, FontWeight? fontWeight, String? fontFamily, bool disableZoom = false}) → TextStyle - Build a TextStyle from an FondeTextVariant.
-
buildTextStyleWithColor(
{required FondeTextVariant variant, required BuildContext context, required Color color, FontWeight? fontWeight, String? fontFamily, bool disableZoom = false}) → TextStyle - Helper method to build a TextStyle with a specific color.