FondeNavigationStateData class
Navigation state data class.
Constructors
-
const
Properties
-
expandedGroupIds
→ List<
String> -
List of IDs of expanded groups.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItemId → String?
-
ID of the selected item (null if nothing is selected).
final
Methods
-
copyWith(
{List< String> ? expandedGroupIds, String? selectedItemId}) → FondeNavigationStateData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited